/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: rumor-tab.h,v 1.6 2006/09/20 09:35:29 bowkenken Exp $
***************************************************************/

#ifndef	RUMOR_TAB_H
#define	RUMOR_TAB_H

/* α */

typedef struct {
	/*  */
	n_msg_t	n_msg_female, n_msg_male;

	/* ʹЯե饰 */
	bool_t	flg_open;

	/* ͥŪʹǿαΥե饰 */
	bool_t	flg_latest;
} rumor_tab_t;

rumor_tab_t	rumor_tab[] = {
	{
		N_MSG_RUMOR_001_FEMALE,
		N_MSG_RUMOR_001_MALE,
		TRUE, FALSE,
	},
	{
		N_MSG_RUMOR_002_FEMALE,
		N_MSG_RUMOR_002_MALE,
		TRUE, FALSE,
	},
	{
		N_MSG_RUMOR_003_FEMALE,
		N_MSG_RUMOR_003_MALE,
		TRUE, FALSE,
	},
	{
		N_MSG_RUMOR_004_FEMALE,
		N_MSG_RUMOR_004_MALE,
		TRUE, FALSE,
	},
	{
		N_MSG_RUMOR_005_FEMALE,
		N_MSG_RUMOR_005_MALE,
		TRUE, FALSE,
	},
	{
		N_MSG_RUMOR_006_FEMALE,
		N_MSG_RUMOR_006_MALE,
		TRUE, FALSE,
	},
	{
		N_MSG_RUMOR_007_FEMALE,
		N_MSG_RUMOR_007_MALE,
		TRUE, FALSE,
	},
	{
		N_MSG_RUMOR_008_FEMALE,
		N_MSG_RUMOR_008_MALE,
		TRUE, FALSE,
	},
	{
		N_MSG_NULL,
		N_MSG_NULL,
		FALSE, FALSE,
	},
};

#endif	/* RUMOR_TAB_H */
